==> esup-canal-stockage-3.4.0-RC-1.zip: CStockage-3.4.0-RC-1/source/org/esupportail/portal/channels/CStockage/channelAction/injac/metadata/MetaDataConstants.java <==
/*
ESUP-portail is a french academic project developed under the GPL (General Public License) augmented according to the following :
A binary or source file developped by ESUP-portail can be used or compiled with products under Apache license.
The official english text of the GPL can be found here : http://www.gnu.org/licenses/gpl.html .
A non official french translation can be found here : http://www.linux-France.org/article/these/gpl.html .
The different kinds of licenses governing the products developed by the Apache foundation can be found here : http://www.apache.org/licenses .
It follows that you can as well as use download contents as well modify and redistribute them provided you respect the GPL terms.
Downloading and using such contents do not provide any guaranty.
Be sure that you have well understood the terms of the license before using the contents it covers.
The ESUP-portail distribution includes the following distributions :
    * UPortal : 
      software developed by JA-SIG (Java Architecture - Special Interest Group)
      You can find the license page here : http://mis105.udel.edu/ja-sig/uportal/license.html
    * CAS :
      SSO solution developed by Yale University
      You can find the project page here : http://www.yale.edu/tp/auth
    * Cocoon :
      XML framework distributed by the Apache foundation under Apache license;
      Please find the full text here : http://cocoon.apache.org/2.1/license.html
    * Mod_dav:
      A DAV module for Apache web server
      You can find the project page here : http://www.webdav.org/mod_dav
    * IMP :
      webmail from Horde application framework
      You can find the project page here : http://www.horde.org
    * . To be completed
*/
package org.esupportail.portal.channels.CStockage.channelAction.injac.metadata;

/**
 * Id: MetaDataConstants.java,v 1.0 30 sept. 2004
 * Copyright (c) 2004 Esup Portail (www.esup-portail.org)
 * Classes: MetaDataConstants
 * Original Author: Yohan Colmant
 * The metadata names
 */
public class MetaDataConstants {
	
	
	
	/** Space and document */
	
	public static final String INJAC_TYPE = "injac-type";
	public static final String INJAC_TYPE_DOCUMENT = "document";
	public static final String INJAC_TYPE_SPACE = "space";	
	
	public static final String DOCUMENT_STATE = "document-state";
	public static final String DOCUMENT_PUBLISHED_STATE = "published";
	public static final String DOCUMENT_REFUSED_STATE = "rejected";
	public static final String DOCUMENT_WAITING_STATE = "waiting";
	public static final String DOCUMENT_EXPIRED_STATE = "expired";
	
	
	public static final String DESCRIPTION = "description";	
	
	
	
	/** Injac space **/
		
	public static final String WRITERS = "writers";
	
	public static final String EDITORS = "editors";
	
	public static final String MANAGERS = "managers";
	
	
	
	public static final String RENDERING_TYPE = "CSSFile";
		
	public static final String DOCUMENT_INJAC_METADATA = "document-injac-metadata";
	
	
	
	
	/** Injac document **/
	
	public static final String DOCUMENT_OWNER = "document-owner";
	
	public static final String PUBLICATION_DATE_BEGIN = "publication-date-begin";
	
	public static final String PUBLICATION_DATE_END = "publication-date-end";
		
	
	public static final String REJECT_CAUSE = "reject-cause";
	

}

==> esup-canal-stockage-4.1-RC-1.zip: CStockage-4.1-RC-1/source/org/esupportail/portal/channels/CStockage/channelAction/injac/metadata/MetaDataConstants.java <==
/*
ESUP-portail is a french academic project developed under the GPL (General Public License) augmented according to the following :
A binary or source file developped by ESUP-portail can be used or compiled with products under Apache license.
The official english text of the GPL can be found here : http://www.gnu.org/licenses/gpl.html .
A non official french translation can be found here : http://www.linux-France.org/article/these/gpl.html .
The different kinds of licenses governing the products developed by the Apache foundation can be found here : http://www.apache.org/licenses .
It follows that you can as well as use download contents as well modify and redistribute them provided you respect the GPL terms.
Downloading and using such contents do not provide any guaranty.
Be sure that you have well understood the terms of the license before using the contents it covers.
The ESUP-portail distribution includes the following distributions :
    * UPortal : 
      software developed by JA-SIG (Java Architecture - Special Interest Group)
      You can find the license page here : http://mis105.udel.edu/ja-sig/uportal/license.html
    * CAS :
      SSO solution developed by Yale University
      You can find the project page here : http://www.yale.edu/tp/auth
    * Cocoon :
      XML framework distributed by the Apache foundation under Apache license;
      Please find the full text here : http://cocoon.apache.org/2.1/license.html
    * Mod_dav:
      A DAV module for Apache web server
      You can find the project page here : http://www.webdav.org/mod_dav
    * IMP :
      webmail from Horde application framework
      You can find the project page here : http://www.horde.org
    * . To be completed
*/
package org.esupportail.portal.channels.CStockage.channelAction.injac.metadata;

/**
 * Id: MetaDataConstants.java,v 1.0 30 sept. 2004
 * Copyright (c) 2004 Esup Portail (www.esup-portail.org)
 * Classes: MetaDataConstants
 * Original Author: Yohan Colmant
 * The metadata names
 */
public class MetaDataConstants {
	
	
	
	/** Space and document */
	
	public static final String INJAC_TYPE = "injac-type";
	public static final String INJAC_TYPE_DOCUMENT = "document";
	public static final String INJAC_TYPE_SPACE = "space";	
	
	public static final String DOCUMENT_STATE = "document-state";
	public static final String DOCUMENT_PUBLISHED_STATE = "published";
	public static final String DOCUMENT_REFUSED_STATE = "rejected";
	public static final String DOCUMENT_WAITING_STATE = "waiting";
	public static final String DOCUMENT_EXPIRED_STATE = "expired";
	
	
	public static final String DESCRIPTION = "description";	
	
	
	
	/** Injac space **/
		
	public static final String WRITERS = "writers";
	
	public static final String EDITORS = "editors";
	
	public static final String MANAGERS = "managers";
	
	
	
	public static final String RENDERING_TYPE = "skin";
		
	public static final String DOCUMENT_INJAC_METADATA = "document-injac-metadata";
	
	
	
	
	/** Injac document **/
	
	public static final String DOCUMENT_OWNER = "document-owner";
	
	public static final String PUBLICATION_DATE_BEGIN = "publication-date-begin";
	
	public static final String PUBLICATION_DATE_END = "publication-date-end";
		
	
	public static final String REJECT_CAUSE = "reject-cause";
	
	
	public static final String ROOT_FILE_NAME = "root-file-name";
	public static final String ROOT_DOC_NAME = "root-doc-name";
	
	

}
